
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  'build_requires' => {
    'Module::Build' => '0.3601'
  },
  'configure_requires' => {
    'Module::Build' => '0.3601'
  },
  'dist_abstract' => 'Install all modules authored by SHARYANTO on CPAN',
  'dist_author' => [
    'Steven Haryanto <stevenharyanto@gmail.com>'
  ],
  'dist_name' => 'Task-BeLike-SHARYANTO-Authored',
  'dist_version' => '0.03',
  'license' => 'perl',
  'module_name' => 'Task::BeLike::SHARYANTO::Authored',
  'recommends' => {},
  'recursive_test_files' => 1,
  'requires' => {
    'Acme::CPANAuthors::Female' => '0',
    'Acme::CPANAuthors::Indonesian' => '0',
    'Any::Renderer::Pretty::Console' => '0',
    'Any::Renderer::Pretty::HTML' => '0',
    'App::HTMLCalendarMonth::Indonesia' => '0',
    'App::OrgUtils' => '0',
    'App::SerializeUtils' => '0',
    'App::UniqFiles' => '0',
    'App::perlmv' => '0',
    'Array::Find' => '0',
    'Array::Functions::Undoable' => '0',
    'Array::Iterator' => '0',
    'Bench' => '0',
    'Business::ID::NIK' => '0',
    'Business::ID::NPWP' => '0',
    'Business::ID::SIM' => '0',
    'Calendar::Indonesia::Holiday' => '0',
    'Config::Ini::OnDrugs' => '0',
    'Data::Dump::Ala::SHARYANTO' => '0',
    'Data::Dump::OneLine' => '0',
    'Data::Dump::PHP' => '0',
    'Data::Dump::Partial' => '0',
    'Data::Dump::Ruby' => '0',
    'Data::Format::Pretty' => '0',
    'Data::Format::Pretty::Console' => '0',
    'Data::Format::Pretty::HTML' => '0',
    'Data::Format::Pretty::JSON' => '0',
    'Data::Format::Pretty::PHP' => '0',
    'Data::Format::Pretty::PHPSerialization' => '0',
    'Data::Format::Pretty::Perl' => '0',
    'Data::Format::Pretty::Ruby' => '0',
    'Data::Format::Pretty::YAML' => '0',
    'Data::ModeMerge' => '0',
    'Data::Sah::Util' => '0',
    'Devel::EndStats' => '0',
    'File::RsyBak' => '0',
    'File::Slurp::Shortcuts' => '0',
    'Finance::Bank::ID::BCA' => '0',
    'Finance::Bank::ID::Mandiri' => '0',
    'Gepok' => '0',
    'Git::Bunch' => '0',
    'HTTP::Daemon::UNIX' => '0',
    'LWP::Protocol::http::SocketUnixAlt' => '0',
    'Language::Expr' => '0',
    'Ledger::Parser' => '0',
    'Lingua::EN::Number::Format::MixWithWords' => '0',
    'Lingua::ID::Number::Format::MixWithWords' => '0',
    'Lingua::ID::Nums2Words' => '0',
    'Lingua::ID::Words2Nums' => '0',
    'Lingua::ZH::PinyinConvert::ID' => '0',
    'Locale::ID::GuessGender::FromFirstName' => '0',
    'Log::Any::Adapter::Callback' => '0',
    'Log::Any::Adapter::ScreenColoredLevel' => '0',
    'Log::Any::App' => '0',
    'Log::Dispatch::Dir' => '0',
    'Object::BlankStr' => '0',
    'Object::NulStr' => '0',
    'Object::SpaceBackStr' => '0',
    'Org::Parser' => '0',
    'Org::To::HTML' => '0',
    'Org::To::Pod' => '0',
    'Org::To::Text' => '0',
    'Parse::Netstat' => '0',
    'Parse::Number::EN' => '0',
    'Parse::Number::ID' => '0',
    'Parse::PhoneNumber::ID' => '0',
    'Passwd::Unix::Alt' => '0',
    'Pod::Weaver::Plugin::SubSpec' => '0',
    'Process::KillTree' => '0',
    'RSS::From::Forum::vBulletin' => '0',
    'SHARYANTO::Utils' => '0',
    'Setup::File' => '0',
    'Setup::File::Symlink' => '0',
    'Setup::Multi' => '0',
    'Setup::Test' => '0',
    'Setup::Text::Snippet' => '0',
    'Setup::Unix::User' => '0',
    'Sub::Spec' => '0',
    'Sub::Spec::BashComplete' => '0',
    'Sub::Spec::Clause::drops_privilege' => '0',
    'Sub::Spec::CmdLine' => '0',
    'Sub::Spec::ConvertArgs::Array' => '0',
    'Sub::Spec::DepChecker' => '0',
    'Sub::Spec::Examples' => '0',
    'Sub::Spec::Exporter' => '0',
    'Sub::Spec::Gen::ForModule' => '0',
    'Sub::Spec::Gen::ReadTable' => '0',
    'Sub::Spec::GetArgs::Argv' => '0',
    'Sub::Spec::GetArgs::Array' => '0',
    'Sub::Spec::GetArgs::GetPost' => '0',
    'Sub::Spec::GetArgs::Hash' => '0',
    'Sub::Spec::HTTP' => '0',
    'Sub::Spec::HTTP::Server' => '0',
    'Sub::Spec::Object' => '0',
    'Sub::Spec::Runner' => '0',
    'Sub::Spec::To::HTML' => '0',
    'Sub::Spec::To::Org' => '0',
    'Sub::Spec::To::Pod' => '0',
    'Sub::Spec::To::Text' => '0',
    'Sub::Spec::URI' => '0',
    'Sub::Spec::URI::http' => '0',
    'Sub::Spec::Use' => '0',
    'Sub::Spec::Wrapper' => '0',
    'Text::sprintfn' => '0',
    'WWW::GudangAPI' => '0'
  },
  'script_files' => []
);


my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
