package Task::BeLike::SHARYANTO::Authored;
# ABSTRACT: Install all modules authored by SHARYANTO on CPAN

# note: list of pkgs generated by generate-pkg-lists-for-tbsha

our $VERSION = '0.03'; # VERSION


1;

__END__
=pod

=head1 NAME

Task::BeLike::SHARYANTO::Authored - Install all modules authored by SHARYANTO on CPAN

=head1 VERSION

version 0.03

=head1 DESCRIPTION

This task will install all modules authored by SHARYANTO currently on CPAN.
Excluded are other Task::* modules, or modules already deletd from CPAN.

=head1 TASK CONTENTS

=head2 Included modules

=head3 L<Acme::CPANAuthors::Female>

=head3 L<Acme::CPANAuthors::Indonesian>

=head3 L<Any::Renderer::Pretty::Console>

=head3 L<Any::Renderer::Pretty::HTML>

=head3 L<App::HTMLCalendarMonth::Indonesia>

=head3 L<App::OrgUtils>

=head3 L<App::UniqFiles>

=head3 L<App::perlmv>

=head3 L<Array::Find>

=head3 L<Array::Functions::Undoable>

=head3 L<Array::Iterator>

=head3 L<Bench>

=head3 L<Business::ID::NIK>

=head3 L<Business::ID::NPWP>

=head3 L<Business::ID::SIM>

=head3 L<Calendar::Indonesia::Holiday>

=head3 L<Config::Ini::OnDrugs>

=head3 L<Data::Dump::Ala::SHARYANTO>

=head3 L<Data::Dump::OneLine>

=head3 L<Data::Dump::PHP>

=head3 L<Data::Dump::Partial>

=head3 L<Data::Dump::Ruby>

=head3 L<Data::Format::Pretty>

=head3 L<Data::Format::Pretty::Console>

=head3 L<Data::Format::Pretty::HTML>

=head3 L<Data::Format::Pretty::JSON>

=head3 L<Data::Format::Pretty::PHP>

=head3 L<Data::Format::Pretty::PHPSerialization>

=head3 L<Data::Format::Pretty::Perl>

=head3 L<Data::Format::Pretty::Ruby>

=head3 L<Data::Format::Pretty::YAML>

=head3 L<Data::ModeMerge>

=head3 L<Data::Sah::Util>

=head3 L<Devel::EndStats>

=head3 L<File::RsyBak>

=head3 L<File::Slurp::Shortcuts>

=head3 L<Finance::Bank::ID::BCA>

=head3 L<Finance::Bank::ID::Mandiri>

=head3 L<Gepok>

=head3 L<Git::Bunch>

=head3 L<HTTP::Daemon::UNIX>

=head3 L<LWP::Protocol::http::SocketUnixAlt>

=head3 L<Language::Expr>

=head3 L<Ledger::Parser>

=head3 L<Lingua::EN::Number::Format::MixWithWords>

=head3 L<Lingua::ID::Number::Format::MixWithWords>

=head3 L<Lingua::ID::Nums2Words>

=head3 L<Lingua::ID::Words2Nums>

=head3 L<Lingua::ZH::PinyinConvert::ID>

=head3 L<Locale::ID::GuessGender::FromFirstName>

=head3 L<Log::Any::Adapter::Callback>

=head3 L<Log::Any::Adapter::ScreenColoredLevel>

=head3 L<Log::Any::App>

=head3 L<Log::Dispatch::Dir>

=head3 L<Object::BlankStr>

=head3 L<Object::NulStr>

=head3 L<Object::SpaceBackStr>

=head3 L<Org::Parser>

=head3 L<Org::To::HTML>

=head3 L<Org::To::Pod>

=head3 L<Org::To::Text>

=head3 L<Parse::Netstat>

=head3 L<Parse::Number::EN>

=head3 L<Parse::Number::ID>

=head3 L<Parse::PhoneNumber::ID>

=head3 L<Passwd::Unix::Alt>

=head3 L<Pod::Weaver::Plugin::SubSpec>

=head3 L<Process::KillTree>

=head3 L<SHARYANTO::Utils>

=head3 L<Setup::File>

=head3 L<Setup::File::Symlink>

=head3 L<Setup::Multi>

=head3 L<Setup::Test>

=head3 L<Setup::Text::Snippet>

=head3 L<Setup::Unix::User>

=head3 L<Sub::Spec>

=head3 L<Sub::Spec::BashComplete>

=head3 L<Sub::Spec::Clause::drops_privilege>

=head3 L<Sub::Spec::CmdLine>

=head3 L<Sub::Spec::ConvertArgs::Array>

=head3 L<Sub::Spec::DepChecker>

=head3 L<Sub::Spec::Examples>

=head3 L<Sub::Spec::Exporter>

=head3 L<Sub::Spec::Gen::ForModule>

=head3 L<Sub::Spec::Gen::ReadTable>

=head3 L<Sub::Spec::GetArgs::Argv>

=head3 L<Sub::Spec::GetArgs::Array>

=head3 L<Sub::Spec::GetArgs::GetPost>

=head3 L<Sub::Spec::GetArgs::Hash>

=head3 L<Sub::Spec::HTTP>

=head3 L<Sub::Spec::HTTP::Server>

=head3 L<Sub::Spec::Object>

=head3 L<Sub::Spec::Runner>

=head3 L<Sub::Spec::To::HTML>

=head3 L<Sub::Spec::To::Org>

=head3 L<Sub::Spec::To::Pod>

=head3 L<Sub::Spec::To::Text>

=head3 L<Sub::Spec::URI>

=head3 L<Sub::Spec::URI::http>

=head3 L<Sub::Spec::Wrapper>

=head3 L<WWW::GudangAPI> =pkg

Version =pkg required because: Acme::CPANAuthors::Female

=head3 L<Acme::CPANAuthors::Indonesian>

=head3 L<Any::Renderer::Pretty::Console>

=head3 L<Any::Renderer::Pretty::HTML>

=head3 L<App::HTMLCalendarMonth::Indonesia>

=head3 L<App::OrgUtils>

=head3 L<App::SerializeUtils>

=head3 L<App::UniqFiles>

=head3 L<App::perlmv>

=head3 L<Array::Find>

=head3 L<Array::Functions::Undoable>

=head3 L<Array::Iterator>

=head3 L<Bench>

=head3 L<Business::ID::NIK>

=head3 L<Business::ID::NPWP>

=head3 L<Business::ID::SIM>

=head3 L<Calendar::Indonesia::Holiday>

=head3 L<Config::Ini::OnDrugs>

=head3 L<Data::Dump::Ala::SHARYANTO>

=head3 L<Data::Dump::OneLine>

=head3 L<Data::Dump::PHP>

=head3 L<Data::Dump::Partial>

=head3 L<Data::Dump::Ruby>

=head3 L<Data::Format::Pretty>

=head3 L<Data::Format::Pretty::Console>

=head3 L<Data::Format::Pretty::HTML>

=head3 L<Data::Format::Pretty::JSON>

=head3 L<Data::Format::Pretty::PHP>

=head3 L<Data::Format::Pretty::PHPSerialization>

=head3 L<Data::Format::Pretty::Perl>

=head3 L<Data::Format::Pretty::Ruby>

=head3 L<Data::Format::Pretty::YAML>

=head3 L<Data::ModeMerge>

=head3 L<Data::Sah::Util>

=head3 L<Devel::EndStats>

=head3 L<File::RsyBak>

=head3 L<File::Slurp::Shortcuts>

=head3 L<Finance::Bank::ID::BCA>

=head3 L<Finance::Bank::ID::Mandiri>

=head3 L<Gepok>

=head3 L<Git::Bunch>

=head3 L<HTTP::Daemon::UNIX>

=head3 L<LWP::Protocol::http::SocketUnixAlt>

=head3 L<Language::Expr>

=head3 L<Ledger::Parser>

=head3 L<Lingua::EN::Number::Format::MixWithWords>

=head3 L<Lingua::ID::Number::Format::MixWithWords>

=head3 L<Lingua::ID::Nums2Words>

=head3 L<Lingua::ID::Words2Nums>

=head3 L<Lingua::ZH::PinyinConvert::ID>

=head3 L<Locale::ID::GuessGender::FromFirstName>

=head3 L<Log::Any::Adapter::Callback>

=head3 L<Log::Any::Adapter::ScreenColoredLevel>

=head3 L<Log::Any::App>

=head3 L<Log::Dispatch::Dir>

=head3 L<Object::BlankStr>

=head3 L<Object::NulStr>

=head3 L<Object::SpaceBackStr>

=head3 L<Org::Parser>

=head3 L<Org::To::HTML>

=head3 L<Org::To::Pod>

=head3 L<Org::To::Text>

=head3 L<Parse::Netstat>

=head3 L<Parse::Number::EN>

=head3 L<Parse::Number::ID>

=head3 L<Parse::PhoneNumber::ID>

=head3 L<Passwd::Unix::Alt>

=head3 L<Pod::Weaver::Plugin::SubSpec>

=head3 L<Process::KillTree>

=head3 L<RSS::From::Forum::vBulletin>

=head3 L<SHARYANTO::Utils>

=head3 L<Setup::File>

=head3 L<Setup::File::Symlink>

=head3 L<Setup::Multi>

=head3 L<Setup::Test>

=head3 L<Setup::Text::Snippet>

=head3 L<Setup::Unix::User>

=head3 L<Sub::Spec>

=head3 L<Sub::Spec::BashComplete>

=head3 L<Sub::Spec::Clause::drops_privilege>

=head3 L<Sub::Spec::CmdLine>

=head3 L<Sub::Spec::ConvertArgs::Array>

=head3 L<Sub::Spec::DepChecker>

=head3 L<Sub::Spec::Examples>

=head3 L<Sub::Spec::Exporter>

=head3 L<Sub::Spec::Gen::ForModule>

=head3 L<Sub::Spec::Gen::ReadTable>

=head3 L<Sub::Spec::GetArgs::Argv>

=head3 L<Sub::Spec::GetArgs::Array>

=head3 L<Sub::Spec::GetArgs::GetPost>

=head3 L<Sub::Spec::GetArgs::Hash>

=head3 L<Sub::Spec::HTTP>

=head3 L<Sub::Spec::HTTP::Server>

=head3 L<Sub::Spec::Object>

=head3 L<Sub::Spec::Runner>

=head3 L<Sub::Spec::To::HTML>

=head3 L<Sub::Spec::To::Org>

=head3 L<Sub::Spec::To::Pod>

=head3 L<Sub::Spec::To::Text>

=head3 L<Sub::Spec::URI>

=head3 L<Sub::Spec::URI::http>

=head3 L<Sub::Spec::Use>

=head3 L<Sub::Spec::Wrapper>

=head3 L<Text::sprintfn>

=head3 L<WWW::GudangAPI>

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

